pm4py.statistics.start\_activities.common package
=================================================

Submodules
----------

pm4py.statistics.start\_activities.common.get module
----------------------------------------------------

.. automodule:: pm4py.statistics.start_activities.common.get
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.start_activities.common
   :members:
   :undoc-members:
   :show-inheritance:
